Method: FFI::Libfuse::FuseOperations#fallocate

Defined in:
lib/ffi/libfuse/fuse_operations.rb

#fallocate(path, mode, offset, len, fuse_file_info) ⇒ Object

This method is abstract.

Allocates space for an open file

This function ensures that required space is allocated for specified file. If this function returns success then any subsequent write request to specified range is guaranteed not to fail because of lack of space on the file system media.

Parameters:

  • path (String)
  • mode (Array<Symbol>)

    allocation mode flags :keep_size :punch_hole :no_hide_stale :collapse_range :zero_range :insert_range :unshare_range see linux/falloc.h

  • offset (Integer)
  • len (Integer)

Returns:

  • 0 or -ve errno



# File 'lib/ffi/libfuse/fuse_operations.rb', line 835