Method: FFI::Libfuse::FuseOperations#fuse_flags

Defined in:
lib/ffi/libfuse/fuse_operations.rb

#fuse_flagsArray<Symbol>

Deprecated.

in Fuse3 use fuse_config object in #init

This method is abstract.
Note:

Not available in Fuse3

Configuration method to set fuse flags

  • :nullpath_ok

Flag indicating that the filesystem can accept a NULL path as the first argument for the following operations: read, write, flush, release, fsync, readdir, releasedir, fsyncdir, ftruncate, fgetattr, lock, ioctl and poll

If this flag is set these operations continue to work on unlinked files even if "-ohard_remove" option was specified.

  • :nopath

Flag indicating that the path need not be calculated for the following operations: read, write, flush, release, fsync, readdir, releasedir, fsyncdir, ftruncate, fgetattr, lock, ioctl and poll

Closely related to flag_nullpath_ok, but if this flag is set then the path will not be calculaged even if the file wasn't unlinked. However the path can still be non-NULL if it needs to be calculated for some other reason.

  • :utime_omit_ok

Flag indicating that the filesystem accepts special UTIME_NOW and UTIME_OMIT values in its utimens operation.

Returns:

  • (Array<Symbol>)

    a list of flags to set capabilities



# File 'lib/ffi/libfuse/fuse_operations.rb', line 698