Method: FFI::Libfuse::FuseOperations#getattr

Defined in:
lib/ffi/libfuse/fuse_operations.rb

#getattr(path, stat, fuse_file_info = nil) ⇒ Integer

This method is abstract.

Get file attributes.

Similar to stat(). The 'st_dev' and 'st_blksize' fields are ignored. The 'st_ino' field is ignored except if the 'use_ino' mount option is given.

Parameters:

  • path (String)
  • stat (Stat)

    to be filled with result information

  • fuse_file_info (FuseFileInfo) (defaults to: nil)

    will always be nil if the file is not currently open, but may also be nil if the file is open.

Returns:

  • (Integer)

    0 for success or -ve Errno value



# File 'lib/ffi/libfuse/fuse_operations.rb', line 127