Method: FFI::Libfuse::FuseOperations#ioctl

Defined in:
lib/ffi/libfuse/fuse_operations.rb

#ioctl(path, cmd, arg, fuse_file_info, flags, data) ⇒ Object

This method is abstract.

Ioctl The size and direction of data is determined by IOC*() decoding of cmd. For _IOC_NONE, data will be NULL, for _IOC_WRITE data is out area, for _IOC_READ in area and if both are set in/out area. In all non-NULL cases, the area is of _IOC_SIZE(cmd) bytes.

Parameters:

  • path (String)
  • cmd (Integer)
  • arg (FFI::Pointer)
  • fuse_file_info (FuseFileInfo)
  • flags (Array<Symbol>)
    • :compat 32bit compat ioctl on 64bit machine
    • :unrestricted not restricted to well-formed ioctls, retry allowed (lowlevel fuse)
    • :retry retry with new iovecs (lowlevel fuse)
    • :dir is a directory file handle
  • data (FFI::Pointer)


# File 'lib/ffi/libfuse/fuse_operations.rb', line 734