Method: FFI::Libfuse::FuseOperations#read_buf

Defined in:
lib/ffi/libfuse/fuse_operations.rb

#read_buf(path, bufp, size, offset, fuse_file_info) ⇒ Object

This method is abstract.

Similar to the #read method, but data is stored and returned in a generic buffer.

No actual copying of data has to take place, the source file descriptor may simply be stored in the buffer for later data transfer.

Parameters:

Returns:

  • 0 success or -ve errno



# File 'lib/ffi/libfuse/fuse_operations.rb', line 795