Method: FFI::Libfuse::FuseOperations#readlink

Defined in:
lib/ffi/libfuse/fuse_operations.rb
This method is abstract.

Resolve the target of a symbolic link

Parameters:

  • path (String)
  • target_buffer (FFI::Pointer)

    The buffer should be filled with a null terminated string. The buffer size argument includes the space for the terminating null character. If the linkname is too long to fit in the buffer, it should be truncated.

  • buffer_size (Integer)

Returns:

  • (Integer)

    0 for success.



# File 'lib/ffi/libfuse/fuse_operations.rb', line 144