Method: FFI::Libfuse::FuseOperations#flock
- Defined in:
- lib/ffi/libfuse/fuse_operations.rb
#flock(path, fuse_file_info, op) ⇒ Object
This method is abstract.
Perform BSD file locking operation
@note: if this method is not implemented, the kernel will still allow file locking to work locally. Hence it is only interesting for network filesystem and similar.
|
|
# File 'lib/ffi/libfuse/fuse_operations.rb', line 815
|