Method: FFI::Libfuse::FuseOperations#ioctl
- Defined in:
- lib/ffi/libfuse/fuse_operations.rb
#ioctl(path, cmd, arg, fuse_file_info, flags, data) ⇒ Object
This method is abstract.
Ioctl The size and direction of data is determined by IOC*() decoding of cmd. For _IOC_NONE, data will be NULL, for _IOC_WRITE data is out area, for _IOC_READ in area and if both are set in/out area. In all non-NULL cases, the area is of _IOC_SIZE(cmd) bytes.
|
|
# File 'lib/ffi/libfuse/fuse_operations.rb', line 734
|