Method: FFI::Libfuse::FuseOperations#open
- Defined in:
- lib/ffi/libfuse/fuse_operations.rb
#open(path, fuse_file_info) ⇒ Integer
This method is abstract.
File open operation
No creation (O_CREAT, O_EXCL) and by default also no truncation (O_TRUNC) flags will be passed to open(). If an application specifies O_TRUNC, fuse first calls truncate() and then open(). Only if 'atomic_o_trunc' has been specified and kernel version is 2.6.24 or later, O_TRUNC is passed on to open.
Unless the 'default_permissions' mount option is given, open should check if the operation is permitted for the given flags.
Optionally open may also return an arbitrary filehandle in the fuse_file_info structure, which will be passed to all file operations.
|
|
# File 'lib/ffi/libfuse/fuse_operations.rb', line 291
|